pub struct Lock {
pub holder: String,
pub expire_at_ms: u64,
pub fencing_token: u64,
}Expand description
A lock record (stored in the state machine). The fencing token increases monotonically and prevents an expired holder from processing the same work again after coming back to life.
Fields
holder: Stringexpire_at_ms: u64fencing_token: u64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Lock
impl<'de> Deserialize<'de> for Lock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Lock
impl StructuralPartialEq for Lock